@@ -35,6 +35,6 @@ def filter(cards, pattern='',
 			invert)
 	
 	matches = [c for c in cards if f(c)]
-	matches.sort(key=lambda card: card.seen_date, reverse=True)
+	# matches.sort(key=lambda card: card.seen_date, reverse=True)
 
 	return matches
